# Examples

Example scripts showing how to use the [ChemistryBiology][msl.kcdb.chemistry_biology.ChemistryBiology], [Physics][msl.kcdb.general_physics.Physics] and [Radiation][msl.kcdb.ionizing_radiation.Radiation] classes. Example scripts are also available in the `msl-kcdb` [repository](https://github.com/MSLNZ/msl-kcdb/tree/main/examples){:target="_blank"}.
